from netbox.views.generic import ObjectView, ObjectListView, ObjectEditView, ObjectDeleteView, BulkImportView, \
    BulkEditView, BulkDeleteView

from ocp_project_plugin.filters import OCPProjectFilter
from ocp_project_plugin.forms import (
    OCPProjectImportForm,
    OCPProjectFilterForm,
    OCPProjectForm,
    OCPProjectBulkEditForm
)
from ocp_project_plugin.models import OCPProject, AppEnvironment
from ocp_project_plugin.tables import OCPProjectTable, AppEnvironmentTable
from utilities.views import register_model_view


class OCPProjectListView(ObjectListView):
    queryset = OCPProject.objects.all()
    filterset = OCPProjectFilter
    filterset_form = OCPProjectFilterForm
    table = OCPProjectTable


class OCPProjectEditView(ObjectEditView):
    """View for editing OCP Project instance."""

    queryset = OCPProject.objects.all()
    form = OCPProjectForm
    default_return_url = "plugins:ocp_project_plugin:ocpproject_list"


class OCPProjectDeleteView(ObjectDeleteView):
    queryset = OCPProject.objects.all()
    default_return_url = "plugins:ocp_project_plugin:ocpproject_list"


class OCPProjectBulkImportView(BulkImportView):
    queryset = OCPProject.objects.all()
    model_form = OCPProjectImportForm
    table = OCPProjectTable
    default_return_url = "plugins:ocp_project_plugin:ocpproject_list"


class OCPProjectBulkEditView(BulkEditView):
    queryset = OCPProject.objects.all()
    filterset = OCPProjectFilter
    table = OCPProjectTable
    form = OCPProjectBulkEditForm


class OCPProjectBulkDeleteView(BulkDeleteView):
    queryset = OCPProject.objects.all()
    table = OCPProjectTable


@register_model_view(OCPProject)
class OCPProjectView(ObjectView):
    template_name = 'ocp_project_plugin/ocp_project/ocp_project.html'
    queryset = OCPProject.objects.all()

    def get_extra_context(self, request, instance):
        app_environment_assignments = AppEnvironment.objects.restrict(request.user, 'view').filter(
            ocp_project=instance
        )
        assignments_table = AppEnvironmentTable(app_environment_assignments, user=request.user)
        assignments_table.configure(request)

        return {
            'assignments_table': assignments_table,
            'assignment_count': AppEnvironment.objects.filter(ocp_project=instance).count(),
            'app_env_list': AppEnvironment.objects.filter(ocp_project=instance)
        }





from django.forms import (
    CharField,
)

from netbox.forms import (
    NetBoxModelBulkEditForm,
    NetBoxModelFilterSetForm,
    NetBoxModelImportForm,
    NetBoxModelForm,
)
from ocp_project_plugin.models import OCPProject
from tenancy.models import Tenant, Contact
from utilities.forms import DynamicModelChoiceField


class OCPProjectForm(NetBoxModelForm):
    """Form for creating a new App Environment object."""
    owner = DynamicModelChoiceField(
        queryset=Contact.objects.all(),
        label="Project Owner",
        help_text="Choose the Project Owner"
    )
    contact = DynamicModelChoiceField(
        queryset=Contact.objects.all(),
        label="Contact E-Mail",
        help_text="Write the e-mail of the contact e.g. ana.meier@domain.com"
    )
    customer = DynamicModelChoiceField(
        queryset=Tenant.objects.all(),
        label="Customer name",
        help_text="Choose the tenant",
    )

    class Meta:
        model = OCPProject

        fields = ["name", "description", "display_name", "owner", "contact", "customer", "docu_url", "workload",
                  "request"]


class OCPProjectFilterForm(NetBoxModelFilterSetForm):
    """Form for filtering App Environment instances."""

    model = OCPProject

    name = CharField(
        required=False,
        label="OCP Project Name",
        help_text="The ocp project name e.g. web-shop",
    )
    description = CharField(
        required=False,
        label="Description",
        help_text="The description of the project e.g. A web shop software",
    )
    display_name = CharField(
        required=False,
        label="Display name",
        help_text="Display Name of the project e.g. Web Shop Shopify"
    )
    owner = CharField(
        required=False,
        label="Owner",
        help_text="Choose the tenant"
    )
    contact = CharField(
        required=False,
        label="Contact E-Mail",
        help_text="Write the e-mail of the contact e.g. ana.meier@domain.com"
    )
    customer = CharField(
        required=False,
        label="Customer name",
        help_text="Choose the tenant"
    )
    docu_url = CharField(
        required=False,
        label="URL",
        help_text="The url of the project documentation",
    )
    workload = CharField(
        required=False,
        label="Workload",
        help_text="The workload contents e.g. Postgres DB, nginx",
    )
    request = CharField(
        required=False,
        label="Jira Request",
        help_text="The jira request id e.g. TICKET1234",
    )


class OCPProjectImportForm(NetBoxModelImportForm):
    name = CharField(
        label="OCP Project Name",
        help_text="The ocp project name e.g. web-shop",
    )
    description = CharField(
        label="Description",
        help_text="The description of the project e.g. A web shop software",
    )
    display_name = CharField(
        label="Display name",
        help_text="Display Name of the project e.g. Web Shop Shopify"
    )
    owner = CharField(
        label="Owner",
        help_text="Choose the tenant"
    )
    contact = CharField(
        label="Contact E-Mail",
        help_text="Write the e-mail of the contact e.g. ana.meier@domain.com"
    )
    customer = CharField(
        label="Customer name",
        help_text="Choose the tenant"
    )
    docu_url = CharField(
        label="URL",
        help_text="The url of the project documentation",
    )
    workload = CharField(
        label="Workload",
        help_text="The workload contents e.g. Postgres DB, nginx",
    )
    request = CharField(
        label="Jira Request",
        help_text="The jira request id e.g. TICKET1234",
    )

    class Meta:
        model = OCPProject

        fields = ["name", "description", "display_name", "owner", "contact", "customer", "docu_url", "workload",
                  "request"]


class OCPProjectBulkEditForm(NetBoxModelBulkEditForm):
    model = OCPProject

    name = CharField(
        required=False,
        label="OCP Project Name",
        help_text="The ocp project name e.g. web-shop",
    )
    description = CharField(
        required=False,
        label="Description",
        help_text="The description of the project e.g. A web shop software",
    )
    display_name = CharField(
        required=False,
        label="Display name",
        help_text="Display Name of the project e.g. Web Shop Shopify"
    )
    owner = CharField(
        required=False,
        label="Owner",
        help_text="Choose the tenant"
    )
    contact = CharField(
        required=False,
        label="Contact E-Mail",
        help_text="Write the e-mail of the contact e.g. ana.meier@domain.com"
    )
    customer = CharField(
        required=False,
        label="Customer name",
        help_text="Choose the tenant"
    )
    docu_url = CharField(
        required=False,
        label="URL",
        help_text="The url of the project documentation",
    )
    workload = CharField(
        required=False,
        label="Workload",
        help_text="The workload contents e.g. Postgres DB, nginx",
    )
    request = CharField(
        required=False,
        label="Jira Request",
        help_text="The jira request id e.g. TICKET1234",
    )



from django.core.validators import RegexValidator
from django.forms import (
    CharField,
    BooleanField, PasswordInput,
)

from netbox.forms import (
    NetBoxModelBulkEditForm,
    NetBoxModelFilterSetForm,
    NetBoxModelImportForm,
    NetBoxModelForm,
)
from ocp_project_plugin.models import AppEnvironment, OCPProject
from utilities.forms import DynamicModelChoiceField


memory_validator = RegexValidator(r"[1-9][0-9]*(Mi|Gi)$", "The input should contain only positive Number, which ends "
                                                          "with Mi (Megabyte) or Gi (Gigabyte)")


class AppEnvironmentForm(NetBoxModelForm):
    """Form for creating a new App Environment object."""
    #requests_memory = CharField(
    #    max_length=5,
    #    label="Memory request",
    #    help_text="The memory value e.g. 200Mi or 1Gi",
    #    validators=[memory_validator],
    #)
    ocp_project = DynamicModelChoiceField(
        queryset=OCPProject.objects.all(),
        label="OCP Project",
        help_text="Choose the ocp project e.g. web shop",
    )

    fieldsets = (
        ('OCP Project', ['ocp_project']),
        ('Environment', ('cluster_env', 'app_env')),
        ('Deployment', ('repo', 'branch', 'access_token', 'path', 'deployment_kind')),
        ('Monitoring', ('monitoring', 'postgres_monitoring')),
        ('Resources', ('limits_cpu', 'limits_memory', 'requests_cpu', 'requests_memory')),
        ('Additional Config', ('mtls', 'egress_ip')),
    )

    class Meta:
        model = AppEnvironment

        fields = ["access_token", "cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip", "deployment_kind", "monitoring",
                  "postgres_monitoring", "ocp_project", "requests_cpu", "requests_memory", "limits_cpu",
                  "limits_memory"]

        widgets = {
            'access_token': PasswordInput(),
        }


class AppEnvironmentFilterForm(NetBoxModelFilterSetForm):
    """Form for filtering App Environment instances."""

    model = AppEnvironment

    app_env = CharField(
        required=False,
        label="App Env",
        help_text="The app Env String used for creating the namespace e.g. tst",
    )
    mtls = BooleanField(
        required=False,
        label="MTLS",
        help_text="Enable if mtls should be used",
    )
    repo = CharField(
        required=False,
        label="Git Repository",
        help_text="Path of git Repository, don't forget the .git at the end e.g. "
                  "https://gitlab.com/example/example-deployment-manifests.git",
    )
    branch = CharField(
        required=False,
        label="Git Branch",
        help_text="The git Branch of the Repository e.g. main"
    )
    path = CharField(
        required=False,
        label="Git Path",
        help_text="Path of the deployment files e.g. overlays/tst"
    )
    egress_ip = CharField(
        required=False,
        label="Egress IP",
        help_text="The egress IP e.g. 10.10.10.10"
    )
    monitoring = BooleanField(
        required=False,
        label="Monitoring",
        help_text="Enable if monitoring should be used",
    )
    postgres_monitoring = BooleanField(
        required=False,
        label="Postgres Monitoring",
        help_text="Enable if postgres monitoring should be used",
    )


class AppEnvironmentImportForm(NetBoxModelImportForm):
    app_env = CharField(
        label="App Env",
        help_text="The app Env String used for creating the namespace e.g. tst",
    )
    mtls = BooleanField(
        required=False,
        label="MTLS",
        help_text="Enable if mtls should be used",
    )
    repo = CharField(
        label="Git Repository",
        help_text="Path of git Repository, don't forget the .git at the end e.g. "
                  "https://gitlab.com/example/example-deployment-manifests.git",
    )
    branch = CharField(
        label="Git Branch",
        help_text="The git Branch of the Repository e.g. main"
    )
    path = CharField(
        label="Git Path",
        help_text="Path of the deployment files e.g. overlays/tst"
    )
    egress_ip = CharField(
        label="Egress IP",
        help_text="The egress IP e.g. 10.10.10.10"
    )
    monitoring = BooleanField(
        required=False,
        label="Monitoring",
        help_text="Enable if monitoring should be used",
    )
    postgres_monitoring = BooleanField(
        required=False,
        label="Postgres Monitoring",
        help_text="Enable if postgres monitoring should be used",
    )

    class Meta:
        model = AppEnvironment

        fields = ["app_env", "mtls", "repo", "branch", "path", "egress_ip", "deployment_kind", "monitoring", "postgres_monitoring",
                  "ocp_project"]


class AppEnvironmentBulkEditForm(NetBoxModelBulkEditForm):
    model = AppEnvironment

    app_env = CharField(
        required=False,
        label="App Env",
        help_text="The app Env String used for creating the namespace e.g. tst",
    )
    mtls = BooleanField(
        required=False,
        label="MTLS",
        help_text="Enable if mtls should be used",
    )
    repo = CharField(
        required=False,
        label="Git Repository",
        help_text="Path of git Repository, don't forget the .git at the end e.g. "
                  "https://gitlab.com/example/example-deployment-manifests.git",
    )
    branch = CharField(
        required=False,
        label="Git Branch",
        help_text="The git Branch of the Repository e.g. main"
    )
    path = CharField(
        required=False,
        label="Git Path",
        help_text="Path of the deployment files e.g. overlays/tst"
    )
    egress_ip = CharField(
        required=False,
        label="Egress IP",
        help_text="The egress IP e.g. 10.10.10.10"
    )
    monitoring = BooleanField(
        required=False,
        label="Monitoring",
        help_text="Enable if monitoring should be used",
    )
    postgres_monitoring = BooleanField(
        required=False,
        label="Postgres Monitoring",
        help_text="Enable if postgres monitoring should be used",
    )



import logging

from django_rq import job, get_queue
from dcim.models import Device
#from ocp_project_plugin.models import AppEnvironment, OCPProject, Collection, Compliance, ServiceMapping
from datetime import datetime
import time
#from ocp_project_plugin.choices import CollectFailChoices, CollectStatusChoices
import ipaddress
#from .ocp_project_plugincollect import CollectDeviceData
#from .ocp_project_plugincustom_exceptions import CollectionException
from django.db.models import Q
#from ocp_project_plugin.choices import ServiceComplianceChoices
#from ocp_project_plugin.git_manager import get_device_config, get_days_after_update
#from ocp_project_plugin.config_manager import get_config_diff
from django.conf import settings

#import git
import os
import yaml
from yaml import SafeLoader
from collections import namedtuple

PLUGIN_SETTINGS = settings.PLUGINS_CONFIG.get('ocp_project_plugin', dict())
GITLAB_PROJECT_URL = PLUGIN_SETTINGS.get('gitlab_project_url', '')
VALUES_PATH = PLUGIN_SETTINGS.get('jira_browse_url', '')

"""
1. Git Repo pullen
2. Überprüfen ob es einen Branch mit dem Ticket Namen schon gibt
3. Neuer Branch erstellen mit dem Ticket Namen
4. Secrets entschlüsseln
5. OCP PRoject/App Environment Model Daten in yaml konvertieren
6. Überprüfen ob OCP Project & App Environment schon existiern in values.yaml
7. YAML Daten dem values.yaml anfügen oder updaten
8. Secrets der Secrets Datei anfügen oder updaten
9. Secret verschlüsseln
10. Mergen
"""


@job("default")
def pull_repository():
    print("1. Git Repo pullen")
    get_queue("default").enqueue("ocp_project_plugin.worker.check_branch_existence")


@job("default")
def check_branch_existence():
    print("2. Überprüfen ob es einen Branch mit dem Ticket Namen schon gibt")
    get_queue("default").enqueue("ocp_project_plugin.worker.new_branch")


@job("default")
def new_branch():
    print("3. Neuer Branch erstellen mit dem Ticket Namen")
    get_queue("default").enqueue("ocp_project_plugin.worker.decrypt_secrets")


@job("default")
def decrypt_secrets():
    print("4. Secrets entschlüsseln")
    get_queue("default").enqueue("ocp_project_plugin.worker.convert_models_to_yaml")


@job("default")
def convert_models_to_yaml():
    print("5. OCPPRoject/AppEnvironment Model Daten in yaml konvertieren")
    get_queue("default").enqueue("ocp_project_plugin.worker.check_if_project_already_exists")


@job("default")
def check_if_project_already_exists():
    print("6. Überprüfen ob OCP Project & App Environment schon existiern in values.yaml")
    get_queue("default").enqueue("ocp_project_plugin.worker.add_data_to_yaml")


@job("default")
def add_data_to_yaml():
    print("7. YAML Daten dem values.yaml anfügen oder updaten")
    get_queue("default").enqueue("ocp_project_plugin.worker.add_secrets_to_yaml")


@job("default")
def add_secrets_to_yaml():
    print("8. Secrets der Secrets Datei anfügen oder updaten")
    get_queue("default").enqueue("ocp_project_plugin.worker.encrypt_secrets")


@job("default")
def encrypt_secrets():
    print("9. Secret verschlüsseln")
    get_queue("default").enqueue("ocp_project_plugin.worker.merge_branch_to_main")


@job("default")
def merge_branch_to_main():
    print("10. Mergen")



import logging

from django.core.validators import RegexValidator
from django.db.models import CharField, BooleanField, ForeignKey, CASCADE, OneToOneField, SET_NULL, PROTECT
from django.urls import reverse
from django_rq import get_queue

from ocp_project_plugin.choices import AppEnvironmentClusterEnvChoices, AppEnvironmentDeploymentKindChoices

from netbox.models import NetBoxModel

memory_validator = RegexValidator(r"[1-9][0-9]*(Mi|Gi)$", "The input should contain only positive Number, which ends "
                                                          "with Mi (Megabyte) or Gi (Gigabyte)")


class OCPProject(NetBoxModel):
    name = CharField(
        max_length=255,
        verbose_name="OCP Project Name",
        help_text="The ocp project name e.g. web-shop",
    )
    description = CharField(
        max_length=255,
        verbose_name="Description",
        help_text="The description of the project e.g. A web shop software",
    )
    display_name = CharField(
        max_length=255,
        verbose_name="Display name",
        help_text="Display Name of the project e.g. Web Shop Shopify"
    )
    owner = ForeignKey(
        to='tenancy.Contact',
        on_delete=PROTECT,
        related_name='ocp_project_owner',
    )
    contact = ForeignKey(
        to='tenancy.Contact',
        on_delete=PROTECT,
        related_name='ocp_project_contact',
    )
    customer = ForeignKey(
        to='tenancy.Tenant',
        on_delete=PROTECT,
        related_name='ocp_project_tenant',
    )
    docu_url = CharField(
        max_length=255,
        verbose_name="URL",
        help_text="The url of the project documentation e.g. https://confluence.com/space/project",
    )
    workload = CharField(
        max_length=255,
        verbose_name="Workload",
        help_text="The workload contents e.g. Postgres DB, nginx",
    )
    request = CharField(
        max_length=255,
        verbose_name="Jira Request",
        help_text="The jira request id e.g. TICKET1234",
    )

    clone_fields = ["name", "description", "display_name", "owner", "contact", "customer", "docu_url", "workload",
                    "request"]

    class Meta:
        ordering = ["name", "description", "display_name", "owner", "contact", "customer", "docu_url", "workload",
                    "request"]

    def __str__(self):
        return f"{self.name} ({self.display_name}-{self.customer})"

    def get_absolute_url(self):
        return reverse("plugins:ocp_project_plugin:ocpproject", kwargs={"pk": self.pk})

    @property
    def docs_url(self):
        return f'https://confluence.ti8m.ch/docs/models/OCPProject/'

    def export_yaml_dict(self):
        return {
            'name': self.name,
            'description': self.description,
            'displayName': self.display_name,
            'customer': self.customer,
            'owner': self.owner,
            'contact': self.contact,
            'workloads': self.workload,
            'request': self.request,
            'url': self.docu_url
        }

    def count_app_environments(self):
        return AppEnvironment.objects.filter(OCPProject=self).count()

    def get_all_app_environments(self):
        return AppEnvironment.objects.filter(OCPProject=self)


class AppEnvironment(NetBoxModel):
    cluster_env = CharField(
        max_length=3,
        choices=AppEnvironmentClusterEnvChoices,
        default=AppEnvironmentClusterEnvChoices.CHOICE_TST,
        verbose_name="Cluster ENV",
        help_text="The Cluster Environment",
    )
    app_env = CharField(
        max_length=20,
        verbose_name="App ENV",
        help_text="The app Env String used for creating the namespace e.g. tst",
    )
    deployment_kind = CharField(
        max_length=20,
        choices=AppEnvironmentDeploymentKindChoices,
        default=AppEnvironmentDeploymentKindChoices.DEPLOYMENT_KIND_NORMAL,
        verbose_name="Deployment Kind",
        help_text="Choose the way how the deployment should work",
    )
    mtls = BooleanField(
        default=False,
        blank=False,
        verbose_name="MTLS",
        help_text="Enable if mtls should be used",
    )
    repo = CharField(
        max_length=255,
        verbose_name="Git Repository",
        help_text="Path of git Repository, don't forget the .git at the end e.g. "
                  "https://gitlab.com/example/example-deployment-manifests.git",
    )
    branch = CharField(
        max_length=20,
        verbose_name="Git Branch",
        help_text="The git Branch of the Repository e.g. main"
    )
    access_token = CharField(
        blank=True,
        max_length=100,
        verbose_name="Git Access Token",
        help_text="The access token of the tst git repo, int & prd are automatically provided"
    )
    path = CharField(
        max_length=100,
        verbose_name="Git Path",
        help_text="Path of the deployment files e.g. overlays/tst"
    )
    egress_ip = OneToOneField(
        to='ipam.IPAddress',
        on_delete=SET_NULL,
        related_name='app_env_egress_ip',
        blank=True,
        null=True,
        verbose_name='Egress IP'
    )
    monitoring = BooleanField(
        default=True,
        verbose_name="Monitoring",
        help_text="Enable if monitoring should be used",
    )
    postgres_monitoring = BooleanField(
        default=False,
        verbose_name="Postgres Monitoring",
        help_text="Enable if postgres monitoring should be used",
    )
    requests_cpu = CharField(
        max_length=5,
        blank=True,
        verbose_name="CPU request",
        help_text="The CPU request value e.g. 1",
    )
    requests_memory = CharField(
        max_length=5,
        blank=True,
        verbose_name="Memory request",
        help_text="The memory value e.g. 200Mi or 1Gi",
        validators=[memory_validator],
    )
    limits_cpu = CharField(
        max_length=5,
        blank=True,
        verbose_name="CPU Limit",
        help_text="The CPU request value e.g. 2",
    )
    limits_memory = CharField(
        max_length=5,
        blank=True,
        verbose_name="Memory Limit",
        help_text="The CPU memory value e.g. 400Mi or 2Gi",
        validators=[memory_validator],
    )
    ocp_project = ForeignKey(OCPProject, on_delete=CASCADE, related_name="app_env_ocp_project")

    clone_fields = ["access_token", "cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip", "deployment_kind",
                    "monitoring", "postgres_monitoring", "ocp_project", "requests_cpu", "requests_memory", "limits_cpu",
                    "limits_memory"]

    class Meta:
        ordering = ["access_token", "cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip", "deployment_kind",
                    "monitoring", "postgres_monitoring", "ocp_project", "requests_cpu", "requests_memory", "limits_cpu",
                    "limits_memory"]

    def __str__(self):
        return f"{self.cluster_env}-{self.app_env} ({self.repo}-{self.branch})"

    def get_absolute_url(self):
        return reverse("plugins:ocp_project_plugin:appenvironment", kwargs={"pk": self.pk})

    @property
    def docs_url(self):
        return f'https://confluence.ti8m.ch/docs/models/AppEnvironment/'

    def save(self, *args, **kwargs):
        get_queue("default").enqueue("ocp_project_plugin.worker.pull_repository")
        super(AppEnvironment, self).save(*args, **kwargs)

    def get_cluster_color(self):
        return AppEnvironmentClusterEnvChoices.colors.get(self.cluster_env)





# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ocp_project_plugin',
 'ocp_project_plugin.api',
 'ocp_project_plugin.fields',
 'ocp_project_plugin.filters',
 'ocp_project_plugin.forms',
 'ocp_project_plugin.migrations',
 'ocp_project_plugin.models',
 'ocp_project_plugin.tables',
 'ocp_project_plugin.templatetags',
 'ocp_project_plugin.views']

package_data = \
{'': ['*'],
 'ocp_project_plugin': ['templates/ocp_project_plugin/*',
                        'templates/ocp_project_plugin/app_environment/*',
                        'templates/ocp_project_plugin/ocp_project/*']}

setup_kwargs = {
    'name': 'ocp-project-plugin',
    'version': '0.0.0.0.144',
    'description': 'Netbox OCP Project Plugin',
    'long_description': '# General\n## Build Project\nTo build the project go to login in the pypi web ui and get your token. Add your token to the local pypi config.\n```\npoetry config pypi-token.pypi pypi-\n```\nAfter you made changes, change the version in the files pyproject.toml and netbox_storage/__init__.py\n\nNow you can build and publish the project.\n```\npoetry publish --build\n```\n\n## Use Project\nLink: https://github.com/netbox-community/netbox-docker/wiki/Using-Netbox-Plugins\n\ndocker-compose build --no-cache && docker-compose build --no-cache && docker-compose up -d\n\n\n## Directory structure\n\n```\n+- api - The API Classes, consitsts of Serializer, URL Mapper and Views\n+- filters - Filters of the models, the implementation of the method search, for searching\n+- forms - The ModelForm, ModelFilterForm, ModelImportForm, ModelBulkEditForm, the forms which will be displayed\n+- migrations - DB Django Migration steps\n+- tables - The ModelTable, which has the configuration on how the table looks like\n+- templates\n  +- netbox_storage - The detail view of each model\n    +- drive - The template content of drive, with base and partition model\n    +- inc - The template content box in the Virtual Machine Model\n    +- partition - The template content of partition, with base and physicalvolume model\n    +- physicalvolume - The template content of physicalvolume with base and linuxvolume model\n    +- volumegroup - The template content of volumegroup with base, logicalvolume and physicalvolume\n+- views - PhysicalvolumeListView, PhysicalvolumeView, PhysicalvolumeEditView, PhysicalvolumeDeleteView, \n           PhysicalvolumeBulkImportView, PhysicalvolumeBulkEditView, PhysicalvolumeBulkDeleteView\n```\n## ERM\n\n![The ERM of the Project](documents/erm.jpg?raw=true "ERM Diagram")\n\n## Queues / Worker\n\n### 1. Job - add_project\n1. Git Repo pullen\n2. Überprüfen ob es einen Branch mit dem Ticket Namen schon gibt\n3. Neuer Branch erstellen mit dem Ticket Namen\n4. Secrets entschlüsseln\n5. OCPPRoject/AppEnvironment Model Daten in yaml konvertieren\n6. YAML Daten dem values.yaml anfügen\n7. Secrets der Secrets Datei anfügen\n8. Secret verschlüsseln\n9. Mergen\n\n\n\nSELECT "ocp_project_plugin_appenvironment"."id", \'\n \'"ocp_project_plugin_appenvironment"."created", \'\n \'"ocp_project_plugin_appenvironment"."last_updated", \'\n \'"ocp_project_plugin_appenvironment"."custom_field_data", \'\n \'"ocp_project_plugin_appenvironment"."cluster_env", \'\n \'"ocp_project_plugin_appenvironment"."app_env", \'\n \'"ocp_project_plugin_appenvironment"."deployment_kind", \'\n \'"ocp_project_plugin_appenvironment"."mtls", \'\n \'"ocp_project_plugin_appenvironment"."repo", \'\n \'"ocp_project_plugin_appenvironment"."branch", \'\n \'"ocp_project_plugin_appenvironment"."access_token", \'\n \'"ocp_project_plugin_appenvironment"."path", \'\n \'"ocp_project_plugin_appenvironment"."egress_ip_id", \'\n \'"ocp_project_plugin_appenvironment"."monitoring", \'\n \'"ocp_project_plugin_appenvironment"."postgres_monitoring", \'\n \'"ocp_project_plugin_appenvironment"."requests_cpu", \'\n \'"ocp_project_plugin_appenvironment"."requests_memory", \'\n \'"ocp_project_plugin_appenvironment"."limits_cpu", \'\n \'"ocp_project_plugin_appenvironment"."limits_memory", \'\n \'"ocp_project_plugin_appenvironment"."ocp_project_id" FROM \'\n \'"ocp_project_plugin_appenvironment" INNER JOIN \'\n \'"ocp_project_plugin_ocpproject" ON \'\n \'("ocp_project_plugin_appenvironment"."ocp_project_id" = \'\n \'"ocp_project_plugin_ocpproject"."id") LEFT OUTER JOIN "ipam_ipaddress" ON \'\n \'("ocp_project_plugin_appenvironment"."egress_ip_id" = "ipam_ipaddress"."id") \'\n \'INNER JOIN "tenancy_contact" ON ("ocp_project_plugin_ocpproject"."owner_id" \'\n \'= "tenancy_contact"."id") INNER JOIN "tenancy_contact" T5 ON \'\n \'("ocp_project_plugin_ocpproject"."contact_id" = T5."id") INNER JOIN \'\n \'"tenancy_tenant" ON ("ocp_project_plugin_ocpproject"."customer_id" = \'\n \'"tenancy_tenant"."id") WHERE \'\n \'"ocp_project_plugin_appenvironment"."ocp_project_id" = %s ORDER BY \'\n \'"ocp_project_plugin_appenvironment"."access_token" ASC, \'\n \'"ocp_project_plugin_appenvironment"."cluster_env" ASC, \'\n \'"ocp_project_plugin_appenvironment"."app_env" ASC, \'\n \'"ocp_project_plugin_appenvironment"."mtls" ASC, \'\n \'"ocp_project_plugin_appenvironment"."repo" ASC, \'\n \'"ocp_project_plugin_appenvironment"."branch" ASC, \'\n \'"ocp_project_plugin_appenvironment"."path" ASC, "ipam_ipaddress"."address" \'\n \'ASC, "ipam_ipaddress"."id" ASC, \'\n \'"ocp_project_plugin_appenvironment"."deployment_kind" ASC, \'\n \'"ocp_project_plugin_appenvironment"."monitoring" ASC, \'\n \'"ocp_project_plugin_appenvironment"."postgres_monitoring" ASC, \'\n \'"ocp_project_plugin_ocpproject"."name" ASC, \'\n \'"ocp_project_plugin_ocpproject"."description" ASC, \'\n \'"ocp_project_plugin_ocpproject"."display_name" ASC, "tenancy_contact"."name" \'\n \'ASC, T5."name" ASC, "tenancy_tenant"."name" ASC, \'\n \'"ocp_project_plugin_ocpproject"."docu_url" ASC, \'\n \'"ocp_project_plugin_ocpproject"."workload" ASC, \'\n \'"ocp_project_plugin_ocpproject"."request" ASC, \'\n \'"ocp_project_plugin_appenvironment"."requests_cpu" ASC, \'\n \'"ocp_project_plugin_appenvironment"."requests_memory" ASC, \'\n \'"ocp_project_plugin_appenvironment"."limits_cpu" ASC, \'\n \'"ocp_project_plugin_appenvironment"."limits_memory" ASC LIMIT 4\'',
    'author': 'Tim Rhomberg',
    'author_email': 'timrhomberg@hotmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
